Importing classes and functions — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- Programming guide »

# Importing classes and functions

Classes and functions are imported inside their module’s parent module so that you can import with:

    from pytilities.delegation import Delegator

instead of:

    from pytilities.delegation.delegator import Delegator

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- Programming guide »